[PATCH util-modular v2] release.sh: remove $MESA_VERSION from the destination location

Emil Velikov emil.l.velikov at gmail.com
Fri Jan 20 14:14:01 UTC 2017


From: Emil Velikov <emil.velikov at collabora.com>

Requested by a number of distribution maintainers. Used starting with
the 17.0 series.

v2: Keep things conditional based on the version.

Signed-off-by: Emil Velikov <emil.velikov at collabora.com>
---
 release.sh | 19 +++++++++++--------
 1 file changed, 11 insertions(+), 8 deletions(-)

diff --git a/release.sh b/release.sh
index f5ea397..fcf2a82 100755
--- a/release.sh
+++ b/release.sh
@@ -574,18 +574,21 @@ process_module() {
     elif [ x"$section" = xmesa ]; then
         host_current=$host_mesa
         mesa_version=`echo $pkg_version | sed 's:-rc.*::'`
-        section_path=archive/$mesa_version
+        section_path=archive
         srv_path="/srv/$host_current/www/$section_path"
         list_to=$list_mesa_announce
         list_cc=$list_mesa_devel
 
-        # Mesa uses separate folder for each release
-        echo "Info: creating mesa directory on web server:"
-        ssh $USER_NAME$hostname mkdir -p $srv_path  &>/dev/null
-        if [ $? -ne 0 ]; then
-            echo "Error: cannot create the path \"$srv_path\" on the web server."
-            cd $top_src
-            return 1
+        # Prior to 17.0.x Mesa uses separate folder for each release
+        if test `echo $mesa_version | cut -d'.' -f1` -lt 17; then
+            section_path=$section_path/$mesa_version
+            echo "Info: creating mesa directory on web server:"
+            ssh $USER_NAME$hostname mkdir -p $srv_path  &>/dev/null
+            if [ $? -ne 0 ]; then
+                echo "Error: cannot create the path \"$srv_path\" on the web server."
+                cd $top_src
+                return 1
+            fi
         fi
     fi
 
-- 
2.11.0



More information about the xorg-devel mailing list